@@ -1,3 +1,5 @@
+import os
+
 from jaaql.db.db_interface import DBInterface
 from jaaql.utilities.utils import time_delta_ms, get_jaaql_root, loc, get_base_url, get_external_url
 from datetime import datetime
@@ -6,10 +8,12 @@ from os.path import join, isdir
 from os import listdir, environ
 from jaaql.interpreter.interpret_jaaql import InterpretJAAQL
 from jaaql.exceptions.http_status_exception import HttpStatusException
-from jaaql.db.db_utils import create_interface
-from jaaql.utilities.crypt_utils import encrypt_raw
+from jaaql.utilities.crypt_utils import encrypt_raw, AES__iv_length
+from jaaql.utilities.utils_no_project_imports import objectify
 import re
-from jaaql.utilities.crypt_utils import AES__iv_length
+from monitor.main import initialise, MARKER__bypass, MARKER__jaaql_bypass
+from jaaql.constants import USERNAME__jaaql, USERNAME__super_db, DB__jaaql, DB__postgres
+
 
 MIGRATION_HISTORY = "migration_history"
 
@@ -25,7 +29,7 @@ ATTR_CHECKSUM = "checksum"
 ATTR_EXECUTION_TIME = "execution_time"
 PATH_MIGRATIONS = "migrations"
 SCRIPT_MIGRATION_HISTORY = "migration_history.sql"
-EXTENSION_SQL = ".sql"
+EXTENSION_JAAQL = ".jaaql"
 
 VERSION_SPLIT = "__"
 WORD_SPLIT = "_"
@@ -36,50 +40,6 @@ REGEX__migration_replacement = r'{{JAAQL__[A-Z_]+}}'
 REGEX__migration_replacement_and_encrypt = r'#{{JAAQL__[A-Z_]+}}'
 
 
-def load_config_file(location: str) -> (str, str, str):
-    ret_role = None
-    ret_databases = None
-    try:
-        the_content = open(location, "r").read()
-
-        if "ROLE=" in the_content:
-            ret_role = the_content.split("ROLE=")[1].split("\r")[0].split("\n")[0].strip()
-        if "DATABASES=" in the_content:
-            ret_databases = the_content.split("DATABASES=")[1].split("\r")[0].split("\n")[0].strip()
-    except:
-        pass
-
-    return ret_role, ret_databases
-
-
-def get_config(role: str, folder_role: str, file_role: str, databases: str,
-               folder_databases: str, file_databases: str):
-    ret_role = "jaaql"
-    ret_databases = ["jaaql"]
-
-    if role is not None:
-        ret_role = role
-    if folder_role is not None:
-        ret_role = folder_role
-    if file_role is not None:
-        ret_role = file_role
-
-    if databases is not None:
-        ret_databases = databases.split(",")
-    if folder_databases is not None:
-        ret_databases = folder_databases.split(",")
-    if file_databases is not None:
-        ret_databases = file_databases.split(",")
-
-    return ret_role, ret_databases
-
-
-def create_interface_for_db(config, super_credentials: str, database: str, sub_role: str):
-    address, port, _, username, password = DBInterface.fracture_uri(super_credentials)
-
-    return create_interface(config, address, port, database, username, password=password, sub_role=sub_role)
-
-
 def replace_options_environment_variables(query: str, parsed_options: dict, crypt_key: bytes, is_deployed: bool, config, fixed_salt: bool):
     last_index = 0
     prepared = ""
@@ -148,13 +108,11 @@ def replace_options_environment_variables(query: str, parsed_options: dict, cryp
     return prepared
 
 
-def run_migrations(db_interface: DBInterface, is_deployed: bool, project_name: str = None, migration_folder: str = None, config=None,
-                   super_credentials: str = None, options: dict = None, key: bytes = None):
+def run_migrations(host: str, bypass_super: str, bypass_jaaql: str, db_interface: DBInterface, is_deployed: bool, project_name: str = None,
+                   migration_folder: str = None, config=None, options: dict = None, key: bytes = None):
     if migration_folder is None:
         migration_folder = join(get_jaaql_root(), PATH_MIGRATIONS)
 
-    base_override_role, base_override_databases = load_config_file(join(migration_folder, "config"))
-
     if project_name is None:
         project_name = PROJECT_JAAQL
 
@@ -165,14 +123,12 @@ def run_migrations(db_interface: DBInterface, is_deployed: bool, project_name: s
 
     statement_load_table = {"query": QUERY_LOAD_TABLE, "parameters": {ATTR_PROJECT_NAME: project_name}}
 
-    dbs = {}
-
     try:
-        migration_history = db_interface.objectify(ij.transform(statement_load_table, conn=conn))
+        migration_history = objectify(ij.transform(statement_load_table, conn=conn))
     except HttpStatusException:
         print("Migration history table does not exist. Creating")
         db_interface.execute_script_file(conn, join(get_jaaql_root(), PATH_MIGRATIONS, SCRIPT_MIGRATION_HISTORY))
-        migration_history = db_interface.objectify(ij.transform(statement_load_table, conn=conn))
+        migration_history = objectify(ij.transform(statement_load_table, conn=conn))
 
     installed_scripts = [cur[ATTR_SCRIPT] for cur in migration_history]
     cur_installed_rank = ([-1] + sorted([cur[ATTR_INSTALLED_RANK] for cur in migration_history]))[-1]
@@ -180,41 +136,37 @@ def run_migrations(db_interface: DBInterface, is_deployed: bool, project_name: s
     version_folders = sorted([version_folder for version_folder in listdir(migration_folder) if
                               isdir(join(migration_folder, version_folder)) and '.' in version_folder])
     for version_folder in version_folders:
-        folder_override_role, folder_override_databases = load_config_file(join(migration_folder, version_folder, "config"))
-
         script_files = sorted([script_file for script_file in listdir(join(migration_folder, version_folder)) if
-                               script_file.endswith(EXTENSION_SQL)])
+                               script_file.endswith(EXTENSION_JAAQL)])
         for script_file in script_files:
-            config_file_name = join(migration_folder, version_folder, script_file.split(EXTENSION_SQL)[0] + ".config")
-            script_override_role, script_override_databases = load_config_file(config_file_name)
             full_name = version_folder + "/" + script_file
-            content = open(join(migration_folder, version_folder, script_file), "r").read()
-            cur_role, cur_databases = get_config(base_override_role, folder_override_role, script_override_role,
-                                                             base_override_databases, folder_override_databases, script_override_databases)
+            actual_file_name = join(migration_folder, version_folder, script_file)
+            content = open(actual_file_name, "r").read()
             content_for_hash = replace_options_environment_variables(content, options, key, is_deployed, config,
                                                                      fixed_salt=True)
             content = replace_options_environment_variables(content, options, key, is_deployed, config,
                                                             fixed_salt=False)
 
-            hash_content = content_for_hash + cur_role + str(cur_databases)
+            hash_content = content_for_hash
             checksum = hashlib.md5(hash_content.encode("UTF-8")).digest()
             checksum = int.from_bytes(checksum[0:3], byteorder="little")
             if full_name not in installed_scripts:
+                config_loc = os.environ.get("JAAQL_CONFIG_LOC", "monitor_config")
+                configs = []
+                for fname in os.listdir(config_loc):
+                    config_name = ".".join(fname.split(".")[0:-1])
+                    configs.append([config_name, fname])
+
+                encoded_configs = [[USERNAME__jaaql, host, USERNAME__jaaql, MARKER__bypass + bypass_super, DB__jaaql],
+                                   [USERNAME__super_db, host, USERNAME__super_db, MARKER__jaaql_bypass + bypass_jaaql, DB__postgres]]
+
                 start_time = datetime.now()
 
-                for db in cur_databases:
-                    if db not in dbs:
-                        dbs[db] = create_interface_for_db(config, super_credentials, db, cur_role)
-                    update_db_interface = dbs[db]
-                    if not hasattr(update_db_interface, "attached_conns"):
-                        update_db_interface.attached_conns = {}
-                    update_db_interface.sub_role = cur_role
-                    if cur_role not in update_db_interface.attached_conns:
-                        update_db_interface.attached_conns[cur_role] = update_db_interface.get_conn()
-                    update_db_interface.execute_script_file(update_db_interface.attached_conns[cur_role], as_content=content)
+                initialise(actual_file_name, content, configs, encoded_configs)
+
                 execution_time = time_delta_ms(start_time, datetime.now())
                 version = script_file.split("__")[0][1:]
-                description = " ".join(script_file.split(VERSION_SPLIT)[1].split(EXTENSION_SQL)[0].split(WORD_SPLIT))
+                description = " ".join(script_file.split(VERSION_SPLIT)[1].split(EXTENSION_JAAQL)[0].split(WORD_SPLIT))
                 ij.transform({
                     "query": QUERY_INS_TABLE,
                     "parameters": {
@@ -235,9 +187,4 @@ def run_migrations(db_interface: DBInterface, is_deployed: bool, project_name: s
                     raise Exception("Migration mismatch for " + script_file + ". Locally calculated checksum " + str(
                         checksum) + " yet in db table found " + str(existing_checksum))
 
-    for cur_db in dbs.values():
-        for cur_conn in cur_db.attached_conns.values():
-            cur_db.put_conn(cur_conn)
-        cur_db.close()
-
     db_interface.put_conn(conn)
